@@ -32,7 +32,7 @@ class MlClient(NamespacedClient):
         Closes one or more anomaly detection jobs. A job can be opened and closed
         multiple times throughout its lifecycle.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-close-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-close-job.html>`_
 
         :arg job_id: The name of the job to close
         :arg body: The URL params optionally sent in the body
@@ -64,7 +64,7 @@ class MlClient(NamespacedClient):
         """
         Deletes a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-delete-calendar.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-delete-calendar.html>`_
 
         :arg calendar_id: The ID of the calendar to delete
         """
@@ -89,7 +89,7 @@ class MlClient(NamespacedClient):
         """
         Deletes scheduled events from a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-delete-calendar-event.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-delete-calendar-event.html>`_
 
         :arg calendar_id: The ID of the calendar to modify
         :arg event_id: The ID of the event to remove from the calendar
@@ -112,7 +112,7 @@ class MlClient(NamespacedClient):
         """
         Deletes anomaly detection jobs from a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-delete-calendar-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-delete-calendar-job.html>`_
 
         :arg calendar_id: The ID of the calendar to modify
         :arg job_id: The ID of the job to remove from the calendar
@@ -136,7 +136,7 @@ class MlClient(NamespacedClient):
         """
         Deletes an existing datafeed.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-delete-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-delete-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to delete
         :arg force: True if the datafeed should be forcefully deleted
@@ -165,7 +165,7 @@ class MlClient(NamespacedClient):
         """
         Deletes expired and unused machine learning data.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-delete-expired-data.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-delete-expired-data.html>`_
 
         :arg body: deleting expired data parameters
         :arg job_id: The ID of the job(s) to perform expired data
@@ -190,7 +190,7 @@ class MlClient(NamespacedClient):
         """
         Deletes a filter.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-delete-filter.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-delete-filter.html>`_
 
         :arg filter_id: The ID of the filter to delete
         """
@@ -215,7 +215,7 @@ class MlClient(NamespacedClient):
         """
         Deletes forecasts from a machine learning job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-delete-forecast.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-delete-forecast.html>`_
 
         :arg job_id: The ID of the job from which to delete forecasts
         :arg forecast_id: The ID of the forecast to delete, can be comma
@@ -244,7 +244,7 @@ class MlClient(NamespacedClient):
         """
         Deletes an existing anomaly detection job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-delete-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-delete-job.html>`_
 
         :arg job_id: The ID of the job to delete
         :arg force: True if the job should be forcefully deleted
@@ -270,7 +270,7 @@ class MlClient(NamespacedClient):
         """
         Deletes an existing model snapshot.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-delete-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-delete-snapshot.html>`_
 
         :arg job_id: The ID of the job to fetch
         :arg snapshot_id: The ID of the snapshot to delete
@@ -301,7 +301,7 @@ class MlClient(NamespacedClient):
         """
         Forces any buffered data to be processed by the job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-flush-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-flush-job.html>`_
 
         :arg job_id: The name of the job to flush
         :arg body: Flush parameters
@@ -331,15 +331,17 @@ class MlClient(NamespacedClient):
         "duration",
         "expires_in",
         "max_model_memory",
+        request_mimetypes=["application/json"],
         response_mimetypes=["application/json"],
     )
-    async def forecast(self, job_id, params=None, headers=None):
+    async def forecast(self, job_id, body=None, params=None, headers=None):
         """
         Predicts the future behavior of a time series by using its historical behavior.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-forecast.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-forecast.html>`_
 
         :arg job_id: The ID of the job to forecast for
+        :arg body: Query parameters can be specified in the body
         :arg duration: The duration of the forecast
         :arg expires_in: The time interval after which the forecast
             expires. Expired forecasts will be deleted at the first opportunity.
@@ -354,6 +356,7 @@ class MlClient(NamespacedClient):
             _make_path("_ml", "anomaly_detectors", job_id, "_forecast"),
             params=params,
             headers=headers,
+            body=body,
         )
 
     @query_params(
@@ -375,7 +378,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves anomaly detection job results for one or more buckets.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-get-bucket.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-get-bucket.html>`_
 
         :arg job_id: ID of the job to get bucket results from
         :arg body: Bucket selection details if not provided in URI
@@ -419,7 +422,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves information about the scheduled events in calendars.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-get-calendar-event.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-get-calendar-event.html>`_
 
         :arg calendar_id: The ID of the calendar containing the events
         :arg end: Get events before this time
@@ -456,7 +459,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves configuration information for calendars.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-get-calendar.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-get-calendar.html>`_
 
         :arg body: The from and size parameters optionally sent in the
             body
@@ -488,7 +491,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves anomaly detection job results for one or more categories.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-get-category.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-get-category.html>`_
 
         :arg job_id: The name of the job
         :arg body: Category selection details if not provided in URI
@@ -525,7 +528,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves usage information for datafeeds.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-get-datafeed-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-get-datafeed-stats.html>`_
 
         :arg datafeed_id: The ID of the datafeeds stats to fetch
         :arg allow_no_datafeeds: Whether to ignore if a wildcard
@@ -552,7 +555,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves configuration information for datafeeds.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-get-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-get-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeeds to fetch
         :arg allow_no_datafeeds: Whether to ignore if a wildcard
@@ -580,7 +583,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves filters.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-get-filter.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-get-filter.html>`_
 
         :arg filter_id: The ID of the filter to fetch
         :arg from_: skips a number of filters
@@ -612,7 +615,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves anomaly detection job results for one or more influencers.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-get-influencer.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-get-influencer.html>`_
 
         :arg job_id: Identifier for the anomaly detection job
         :arg body: Influencer selection criteria
@@ -650,7 +653,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves usage information for anomaly detection jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-get-job-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-get-job-stats.html>`_
 
         :arg job_id: The ID of the jobs stats to fetch
         :arg allow_no_jobs: Whether to ignore if a wildcard expression
@@ -677,7 +680,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves configuration information for anomaly detection jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-get-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-get-job.html>`_
 
         :arg job_id: The ID of the jobs to fetch
         :arg allow_no_jobs: Whether to ignore if a wildcard expression
@@ -712,7 +715,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves information about model snapshots.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-get-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-get-snapshot.html>`_
 
         :arg job_id: The ID of the job to fetch
         :arg body: Model snapshot selection criteria
@@ -759,7 +762,7 @@ class MlClient(NamespacedClient):
         Retrieves overall bucket results that summarize the bucket results of multiple
         anomaly detection jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-get-overall-buckets.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-get-overall-buckets.html>`_
 
         :arg job_id: The job IDs for which to calculate overall bucket
             results
@@ -813,7 +816,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves anomaly records for an anomaly detection job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-get-record.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-get-record.html>`_
 
         :arg job_id: The ID of the job
         :arg body: Record selection criteria
@@ -848,22 +851,24 @@ class MlClient(NamespacedClient):
         """
         Returns defaults and limits used by machine learning.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/get-ml-info.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/get-ml-info.html>`_
         """
         return await self.transport.perform_request(
             "GET", "/_ml/info", params=params, headers=headers
         )
 
     @query_params(
+        request_mimetypes=["application/json"],
         response_mimetypes=["application/json"],
     )
-    async def open_job(self, job_id, params=None, headers=None):
+    async def open_job(self, job_id, body=None, params=None, headers=None):
         """
         Opens one or more anomaly detection jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-open-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-open-job.html>`_
 
         :arg job_id: The ID of the job to open
+        :arg body: Query parameters can be specified in the body
         """
         if job_id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'job_id'.")
@@ -873,6 +878,7 @@ class MlClient(NamespacedClient):
             _make_path("_ml", "anomaly_detectors", job_id, "_open"),
             params=params,
             headers=headers,
+            body=body,
         )
 
     @query_params(
@@ -883,7 +889,7 @@ class MlClient(NamespacedClient):
         """
         Posts scheduled events in a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-post-calendar-event.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-post-calendar-event.html>`_
 
         :arg calendar_id: The ID of the calendar to modify
         :arg body: A list of events
@@ -910,7 +916,7 @@ class MlClient(NamespacedClient):
         """
         Sends data to an anomaly detection job for analysis.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-post-data.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-post-data.html>`_
 
         :arg job_id: The name of the job receiving the data
         :arg body: The data to process
@@ -942,7 +948,7 @@ class MlClient(NamespacedClient):
         """
         Previews a datafeed.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-preview-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-preview-datafeed.html>`_
 
         :arg body: The datafeed config and job config with which to
             execute the preview
@@ -964,7 +970,7 @@ class MlClient(NamespacedClient):
         """
         Instantiates a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-put-calendar.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-put-calendar.html>`_
 
         :arg calendar_id: The ID of the calendar to create
         :arg body: The calendar details
@@ -989,7 +995,7 @@ class MlClient(NamespacedClient):
         """
         Adds an anomaly detection job to a calendar.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-put-calendar-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-put-calendar-job.html>`_
 
         :arg calendar_id: The ID of the calendar to modify
         :arg job_id: The ID of the job to add to the calendar
@@ -1017,7 +1023,7 @@ class MlClient(NamespacedClient):
         """
         Instantiates a datafeed.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-put-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-put-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to create
         :arg body: The datafeed config
@@ -1051,7 +1057,7 @@ class MlClient(NamespacedClient):
         """
         Instantiates a filter.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-put-filter.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-put-filter.html>`_
 
         :arg filter_id: The ID of the filter to create
         :arg body: The filter details
@@ -1080,7 +1086,7 @@ class MlClient(NamespacedClient):
         """
         Instantiates an anomaly detection job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-put-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-put-job.html>`_
 
         :arg job_id: The ID of the job to create
         :arg body: The job
@@ -1119,7 +1125,7 @@ class MlClient(NamespacedClient):
         """
         Reverts to a specific snapshot.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-revert-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-revert-snapshot.html>`_
 
         :arg job_id: The ID of the job to fetch
         :arg snapshot_id: The ID of the snapshot to revert to
@@ -1156,7 +1162,7 @@ class MlClient(NamespacedClient):
         Sets a cluster wide upgrade_mode setting that prepares machine learning indices
         for an upgrade.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-set-upgrade-mode.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-set-upgrade-mode.html>`_
 
         :arg enabled: Whether to enable upgrade_mode ML setting or not.
             Defaults to false.
@@ -1178,7 +1184,7 @@ class MlClient(NamespacedClient):
         """
         Starts one or more datafeeds.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-start-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-start-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to start
         :arg body: The start datafeed parameters
@@ -1213,7 +1219,7 @@ class MlClient(NamespacedClient):
         """
         Stops one or more datafeeds.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-stop-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-stop-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to stop
         :arg body: The URL params optionally sent in the body
@@ -1252,7 +1258,7 @@ class MlClient(NamespacedClient):
         """
         Updates certain properties of a datafeed.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-update-datafeed.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-update-datafeed.html>`_
 
         :arg datafeed_id: The ID of the datafeed to update
         :arg body: The datafeed update settings
@@ -1286,7 +1292,7 @@ class MlClient(NamespacedClient):
         """
         Updates the description of a filter, adds items, or removes items.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-update-filter.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-update-filter.html>`_
 
         :arg filter_id: The ID of the filter to update
         :arg body: The filter update
@@ -1311,7 +1317,7 @@ class MlClient(NamespacedClient):
         """
         Updates certain properties of an anomaly detection job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-update-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-update-job.html>`_
 
         :arg job_id: The ID of the job to create
         :arg body: The job update settings
@@ -1338,7 +1344,7 @@ class MlClient(NamespacedClient):
         """
         Updates certain properties of a snapshot.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-update-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-update-snapshot.html>`_
 
         :arg job_id: The ID of the job to fetch
         :arg snapshot_id: The ID of the snapshot to update
@@ -1418,7 +1424,7 @@ class MlClient(NamespacedClient):
         """
         Deletes an existing data frame analytics job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/delete-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/delete-dfanalytics.html>`_
 
         :arg id: The ID of the data frame analytics to delete
         :arg force: True if the job should be forcefully deleted
@@ -1443,7 +1449,7 @@ class MlClient(NamespacedClient):
         """
         Evaluates the data frame analytics for an annotated index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/evaluate-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/evaluate-dfanalytics.html>`_
 
         :arg body: The evaluation definition
         """
@@ -1469,7 +1475,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves configuration information for data frame analytics jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/get-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/get-dfanalytics.html>`_
 
         :arg id: The ID of the data frame analytics to fetch
         :arg allow_no_match: Whether to ignore if a wildcard expression
@@ -1502,7 +1508,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves usage information for data frame analytics jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/get-dfanalytics-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/get-dfanalytics-stats.html>`_
 
         :arg id: The ID of the data frame analytics stats to fetch
         :arg allow_no_match: Whether to ignore if a wildcard expression
@@ -1531,7 +1537,7 @@ class MlClient(NamespacedClient):
         """
         Instantiates a data frame analytics job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/put-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/put-dfanalytics.html>`_
 
         :arg id: The ID of the data frame analytics to create
         :arg body: The data frame analytics configuration
@@ -1559,7 +1565,7 @@ class MlClient(NamespacedClient):
         """
         Starts a data frame analytics job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/start-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/start-dfanalytics.html>`_
 
         :arg id: The ID of the data frame analytics to start
         :arg body: The start data frame analytics parameters
@@ -1588,7 +1594,7 @@ class MlClient(NamespacedClient):
         """
         Stops one or more data frame analytics jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/stop-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/stop-dfanalytics.html>`_
 
         :arg id: The ID of the data frame analytics to stop
         :arg body: The stop data frame analytics parameters
@@ -1619,7 +1625,7 @@ class MlClient(NamespacedClient):
         Deletes an existing trained inference model that is currently not referenced by
         an ingest pipeline.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/delete-trained-models.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/delete-trained-models.html>`_
 
         :arg model_id: The ID of the trained model to delete
         """
@@ -1643,7 +1649,7 @@ class MlClient(NamespacedClient):
         """
         Explains a data frame analytics config.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/explain-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/explain-dfanalytics.html>`_
 
         :arg body: The data frame analytics config to explain
         :arg id: The ID of the data frame analytics to explain
@@ -1671,7 +1677,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves configuration information for a trained inference model.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/get-trained-models.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/get-trained-models.html>`_
 
         :arg model_id: The ID of the trained models to fetch
         :arg allow_no_match: Whether to ignore if a wildcard expression
@@ -1714,7 +1720,7 @@ class MlClient(NamespacedClient):
         """
         Retrieves usage information for trained inference models.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/get-trained-models-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/get-trained-models-stats.html>`_
 
         :arg model_id: The ID of the trained models stats to fetch
         :arg allow_no_match: Whether to ignore if a wildcard expression
@@ -1743,7 +1749,7 @@ class MlClient(NamespacedClient):
         """
         Creates an inference trained model.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/put-trained-models.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/put-trained-models.html>`_
 
         :arg model_id: The ID of the trained models to store
         :arg body: The trained model configuration
@@ -1771,7 +1777,7 @@ class MlClient(NamespacedClient):
         """
         Estimates the model memory
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-apis.html>`_
 
         :arg body: The analysis config, plus cardinality estimates for
             fields it references
@@ -1795,7 +1801,7 @@ class MlClient(NamespacedClient):
         """
         Updates certain properties of a data frame analytics job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/update-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/update-dfanalytics.html>`_
 
         :arg id: The ID of the data frame analytics to update
         :arg body: The data frame analytics settings to update
@@ -1823,7 +1829,7 @@ class MlClient(NamespacedClient):
         """
         Upgrades a given job snapshot to the current major version.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-upgrade-job-model-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-upgrade-job-model-snapshot.html>`_
 
         :arg job_id: The ID of the job
         :arg snapshot_id: The ID of the snapshot
@@ -1860,7 +1866,7 @@ class MlClient(NamespacedClient):
         """
         Deletes a model alias that refers to the trained model
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/delete-trained-models-aliases.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/delete-trained-models-aliases.html>`_
 
         :arg model_id: The trained model where the model alias is
             assigned
@@ -1887,7 +1893,7 @@ class MlClient(NamespacedClient):
         """
         Previews that will be analyzed given a data frame analytics config.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/preview-dfanalytics.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/preview-dfanalytics.html>`_
 
         :arg body: The data frame analytics config to preview
         :arg id: The ID of the data frame analytics to preview
@@ -1912,7 +1918,7 @@ class MlClient(NamespacedClient):
         Creates a new model alias (or reassigns an existing one) to refer to the
         trained model
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/put-trained-models-aliases.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/put-trained-models-aliases.html>`_
 
         :arg model_id: The trained model where the model alias should be
             assigned
@@ -1954,7 +1960,7 @@ class MlClient(NamespacedClient):
         Finds the structure of a text file. The text file must contain data that is
         suitable to be ingested into Elasticsearch.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/find-structure.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/find-structure.html>`_
 
         .. warning::
 
@@ -2014,7 +2020,7 @@ class MlClient(NamespacedClient):
         """
         Resets an existing anomaly detection job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.16/ml-reset-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-reset-job.html>`_
 
         :arg job_id: The ID of the job to reset
         :arg wait_for_completion: Should this request wait until the
@@ -2029,3 +2035,42 @@ class MlClient(NamespacedClient):
             params=params,
             headers=headers,
         )
+
+    @query_params(
+        "allow_no_match",
+        response_mimetypes=["application/json"],
+    )
+    async def get_model_snapshot_upgrade_stats(
+        self, job_id, snapshot_id, params=None, headers=None
+    ):
+        """
+        Gets stats for anomaly detection job model snapshot upgrades that are in
+        progress.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.17/ml-get-job-model-snapshot-upgrade-stats.html>`_
+
+        :arg job_id: The ID of the job. May be a wildcard, comma
+            separated list or `_all`.
+        :arg snapshot_id: The ID of the snapshot. May be a wildcard,
+            comma separated list or `_all`.
+        :arg allow_no_match: Whether to ignore if a wildcard expression
+            matches no jobs or no snapshots. (This includes the `_all` string.)
+        """
+        for param in (job_id, snapshot_id):
+            if param in SKIP_IN_PATH:
+                raise ValueError("Empty value passed for a required argument.")
+
+        return await self.transport.perform_request(
+            "GET",
+            _make_path(
+                "_ml",
+                "anomaly_detectors",
+                job_id,
+                "model_snapshots",
+                snapshot_id,
+                "_upgrade",
+                "_stats",
+            ),
+            params=params,
+            headers=headers,
+        )
